@@ -176,6 +176,11 @@ class ADCBaseElement:
         """Return state description as reported by ADC."""
         return self._attribs_raw.get("displayStateText")
 
+    @property
+    def debug_data(self) -> dict:
+        """Return data that is helpful for debugging."""
+        return self._attribs_raw
+
     # #
     # PLACEHOLDERS
     # #
@@ -366,7 +371,7 @@ class ADCLight(DesiredStateMixin, ADCBaseElement):
             and self._attribs_raw.get("remoteCommandsEnabled", False)
             and self._attribs_raw.get("hasPermissionToChangeState", False)
             and self.state
-            in [self.DeviceState.ON, self.DeviceState.OFF, self.DeviceState.LEVELCHANGE]
+            in [self.DeviceState.ON, self.DeviceState.OFF, self.DeviceState.LEVELCHANGE]  # type: ignore
         )
 
     @property
